Teen desperate for a baby kills woman who was 8 months pregnant, cuts out baby | Fox News Latino
Description: They met at a mall and then went to Salinas’ home, where she said she had more items to give her.
Keywords: Rio Grande,Tamaulipas,Rio,Mexico,Once,mother died,abortion,Texas,baby,house,Salinas,Facebook
Date: 2014-12-23

# Teen desperate for a baby kills woman who was 8 months pregnant, cuts out baby

Published December 23, 2014
Fox News Latino

- Nathaly Cartas Leon in an undated picture.Facebook

- Nathaly Cartas Leon in an undated picture.Facebook

Next Slide Previous Slide

In a page taken from the most gruesome of books, a 17-year-old girl from Reynosa, Mexico lured an 8-months-pregnant woman to her home and killed her to try and steal her unborn baby.

Nathaly Cartas Leon, 20, had “met” Guadalupe Salinas Hernández on Facebook and had gratefully accepted her offer to give the mom-to-be a few baby items she needed. They met at a mall and then went to Salinas’ home, where she said she had more stuff to give her.

Once there, investigators said, Salinas beat Cartas to death with a blunt object and then proceeded to open her belly with a kitchen knife. The motive, police said: obsessive love. According to authorities, Salinas had an abortion back in June and had not told her boyfriend, who still believed she was pregnant and was looking forward to the birth.

It is not clear whether Salinas’ abortion was intentional or not.

After the gruesome killing and removal of the newborn, the teen hurried to the hospital and tried to save him, claiming the child was stillborn at home. But the fetus had stopped breathing when her mother died and could not be saved.

It didn’t take much for the doctors at the hospital to realize that the baby had not come from Salinas’ womb and they contacted police.

“I don’t regret it, I don’t regret,” local newspapers quote Salinas as saying. The body of the young mother was found in a shrub close to the killer’s house. Investigators are still trying to determine if she had an accomplice.

Reynosa is a border city in the northern part of Tamaulipas, Mexico. It is located on the southern bank of the Rio Grande, directly across the border from Hidalgo, Texas.

Like us on Facebook
Follow us on Twitter & Instagram

- Print
- Email
- Share
- Comments
- Recommend
- Tweet

## Related Video

Yuca mash with spicy Peruvian touch

## Related Slideshow

The most bizarre border busts

Best pix of the week

Related Stories
  Schools using mariachi music to bring together teachers, parents

## Share This Article

- View Article

You must login to comment.

View Article

## Follow Fox News Latino

#### Get Our Free Newsletter

Newsletter Signup

Advertisement

## More Stories

- ### NYC Mayor de Blasio met by boos, jeers during NYPD graduation ceremony

- ### GPS used to track some migrants caught crossing U.S.-Mexico border illegally

- ### Boyfriend of missing teen found wandering Arizona interstate

- ### White middle school teacher in the Bronx files discrimination suit against NYC

- ### Move over Kim Kardashian, Indianara Carvalho crowned Miss BumBum 2014

- ### Blood on the sand: Female matador, four others gored by enormous bull in Mexico City

- ### Antonio Banderas on his new girlfriend: 'We are in the process of getting to know each other'

- ### Forget fireworks, Mexico's Popocatépetl volcano puts on an explosive New Year's show

Advertisement

## Also on the web

- Avión de AirAsia no tenía permiso para volar el día de su desaparición
- Barack Obama y Enrique Peña Nieto se reunirán en la Casa Blanca para tratar relaciones bilaterales
- Policía en Atlanta es investigado por disparar "accidentalmente" contra su esposa
- Cuba está lista para celebrar los 56 años de la revolución en la Isla
- Casos de autoridades involucradas en crímenes está acabando con la confianza de los ciudadanos mexicanos

- Sofia Vergara -- Engaged to Joe Manganiello ... But Don't Tell Her Finger! (PHOTO)
- Salma Hayek -- Mama Mia ... That's Some Body! (PHOTO)
- Jennifer Lopez -- Drunk Driver Nailed ... That's How the D.A. Rolls
- Christina Aguilera -- Disneyland Tantrum ... Calls Mickey an A**hole
- Jose Canseco -- Gunshot Finger Making Incredible Recovery ... Says Ex

- 31 Hilarious Kids Who Know Exactly What They Want In Life
- 11 Babies That Hilariously Look Just Like Celebrities
- 23 People Who Will Make You Feel Brilliant
- 27 Cats That Look Like Something Else
- 21 Animals With Unique and Adorable Markings

- Iniesta no comprende ataques a Messi
- Gasol dice que D'Antoni está 'estropeando' su temporada
- Inglaterra derrota a Brasil
- Con 23 triples los Rockets aplastaron a los Warriors
- Sexygalería: Gisele Bundchen, consiente mucho a Tom Brady

- Chiquis Rivera shares heartbreaking message about mom Jenni Rivera
- 10 Latino celeb New Years bashes that made us jealous!
- 10 Fashion myths Latinas need to stop believing
- Ashton Kutcher and Mila Kunis may be married!
- Kim Kardashian addresses ALL the rumors in New Year's Twitter rant

- EXCLUSIVE: Pitbull Talks Performing for NYE & Bringing "Flavor" to 2015
- Zoe Saldaña Reveals the Names of Her Twins!
- How Your Favorite Celebs Celebrated the New Year!
- EXCLUSIVE: WWE's Rosa Mendes Talks 'Total Divas' & Her Costa Rican Roots
- Sofia Vergara's Best Selfies, Ever!